Module task_context

Module task_context 

Structs

PipelineContext
Identity of the running pipeline and the data item being processed.
TaskContext
Runtime dependencies and control tokens for a single pipeline task.
TaskContextBuilder
Fluent builder for TaskContext.