pub struct Model {
pub id: String,
pub slug: String,
pub user_id: String,
pub data_id: String,
pub dataset_id: String,
pub label: Option<String>,
pub node_type: String,
pub indexed_fields: Value,
pub attributes: Option<Value>,
pub created_at: DateTime<Utc>,
}Fields
id: Stringslug: Stringuser_id: Stringdata_id: Stringdataset_id: Stringlabel: Option<String>node_type: Stringindexed_fields: Valueattributes: Option<Value>created_at: DateTime<Utc>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Model
impl<'de> Deserialize<'de> for Model
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Model, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Model, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Model
Sourceimpl From<Model> for ActiveModel
impl From<Model> for ActiveModel
Sourcefn from(m: Model) -> ActiveModel
fn from(m: Model) -> ActiveModel
Converts to this type from the input type.
Sourceimpl FromQueryResult for Model
impl FromQueryResult for Model
Sourcefn from_query_result(row: &QueryResult, pre: &str) -> Result<Model, DbErr>
fn from_query_result(row: &QueryResult, pre: &str) -> Result<Model, DbErr>
Instantiate a Model from a QueryResult Read more
Sourcefn from_query_result_optional(
res: &QueryResult,
pre: &str,
) -> Result<Option<Self>, DbErr>
fn from_query_result_optional( res: &QueryResult, pre: &str, ) -> Result<Option<Self>, DbErr>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option
Sourcefn from_query_result_nullable(
res: &QueryResult,
pre: &str,
) -> Result<Self, TryGetError>
fn from_query_result_nullable( res: &QueryResult, pre: &str, ) -> Result<Self, TryGetError>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option Read more
Sourcefn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
fn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
Sourceimpl IntoActiveModel<ActiveModel> for Model
impl IntoActiveModel<ActiveModel> for Model
Sourcefn into_active_model(self) -> ActiveModel
fn into_active_model(self) -> ActiveModel
Method to call to perform the conversion
Sourceimpl ModelTrait for Model
impl ModelTrait for Model
type Entity = Entity
Sourcefn get(
&self,
c: <<Model as ModelTrait>::Entity as EntityTrait>::Column,
) -> Value
fn get( &self, c: <<Model as ModelTrait>::Entity as EntityTrait>::Column, ) -> Value
Get the Value of a column from an Entity
Sourcefn set(
&mut self,
c: <<Model as ModelTrait>::Entity as EntityTrait>::Column,
v: Value,
)
fn set( &mut self, c: <<Model as ModelTrait>::Entity as EntityTrait>::Column, v: Value, )
Set the Value of a column in an Entity
Find related Models
Sourcefn delete<'a, 'async_trait, A, C>(
self,
db: &'a C,
) -> Pin<Box<dyn Future<Output = Result<DeleteResult, DbErr>> + Send + 'async_trait>>where
'a: 'async_trait,
Self: IntoActiveModel<A> + 'async_trait,
C: ConnectionTrait + 'async_trait,
A: ActiveModelTrait<Entity = Self::Entity> + ActiveModelBehavior + Send + 'a + 'async_trait,
fn delete<'a, 'async_trait, A, C>(
self,
db: &'a C,
) -> Pin<Box<dyn Future<Output = Result<DeleteResult, DbErr>> + Send + 'async_trait>>where
'a: 'async_trait,
Self: IntoActiveModel<A> + 'async_trait,
C: ConnectionTrait + 'async_trait,
A: ActiveModelTrait<Entity = Self::Entity> + ActiveModelBehavior + Send + 'a + 'async_trait,
Delete a model
Sourceimpl Serialize for Model
impl Serialize for Model
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Model
Sourceimpl TryFrom<ActiveModel> for Model
impl TryFrom<ActiveModel> for Model
Sourceimpl TryIntoModel<Model> for ActiveModel
impl TryIntoModel<Model> for ActiveModel