pub struct SeaOrmSessionStore { /* private fields */ }Expand description
SeaORM-backed session store using the session_qa_entries table.
Works with any SeaORM-supported database (SQLite, PostgreSQL, MySQL). Runs its own schema migration on creation so the table is only created when this backend is actually used (not as part of the generic database init).
Implementations
Sourceimpl SeaOrmSessionStore
impl SeaOrmSessionStore
Sourcepub async fn new(
db: Arc<DatabaseConnection>,
) -> Result<SeaOrmSessionStore, SessionError>
pub async fn new( db: Arc<DatabaseConnection>, ) -> Result<SeaOrmSessionStore, SessionError>
Create a new store and run the session schema migration.