StorageTrait

Trait StorageTrait 

pub trait StorageTrait: Send + Sync {
    // Required methods
    fn store<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        data: &'life1 [u8],
        file_name: &'life2 str,
    ) -> Pin<Box<dyn Future<Output = Result<String, StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             Self: 'async_trait;
    fn store_stream_dyn<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        reader: &'life1 mut (dyn AsyncRead + Unpin + Send),
        file_name: &'life2 str,
    ) -> Pin<Box<dyn Future<Output = Result<String, StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             Self: 'async_trait;
    fn create_writer<'life0, 'life1, 'async_trait>(
        &'life0 self,
        file_name: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<StorageWriter, StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             Self: 'async_trait;
    fn retrieve<'life0, 'life1, 'async_trait>(
        &'life0 self,
        location: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<u8>, StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             Self: 'async_trait;
    fn exists<'life0, 'life1, 'async_trait>(
        &'life0 self,
        location: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<bool, StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             Self: 'async_trait;
    fn delete<'life0, 'life1, 'async_trait>(
        &'life0 self,
        location: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<(), StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             Self: 'async_trait;
    fn get_full_path(&self, location: &str) -> PathBuf;
    fn base_path(&self) -> &str;
    fn initialize<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<(), StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
    fn remove_all<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<(), StorageError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
}

Required Methods

fn store<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, data: &'life1 [u8], file_name: &'life2 str, ) -> Pin<Box<dyn Future<Output = Result<String, StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, Self: 'async_trait,

Store data at a specific path and return the storage location

fn store_stream_dyn<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, reader: &'life1 mut (dyn AsyncRead + Unpin + Send), file_name: &'life2 str, ) -> Pin<Box<dyn Future<Output = Result<String, StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, Self: 'async_trait,

Store data from an async reader (streaming) and return the storage location. This is the object-safe version; for a generic version see StorageExt::store_stream.

fn create_writer<'life0, 'life1, 'async_trait>( &'life0 self, file_name: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<StorageWriter, StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Self: 'async_trait,

Create a writer for chunk-based storage Allows writing data in chunks without loading entire content into memory

fn retrieve<'life0, 'life1, 'async_trait>( &'life0 self, location: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<Vec<u8>, StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Self: 'async_trait,

Retrieve data from storage location

fn exists<'life0, 'life1, 'async_trait>( &'life0 self, location: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<bool, StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Self: 'async_trait,

Check if data exists at location

fn delete<'life0, 'life1, 'async_trait>( &'life0 self, location: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<(), StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Self: 'async_trait,

Delete data at location

fn get_full_path(&self, location: &str) -> PathBuf

Get the full path for a location

fn base_path(&self) -> &str

Return the base directory of this storage backend as a string. Used to construct file:// URIs for stored files. Returns an empty string for backends that have no filesystem path (e.g. mock, S3).

fn initialize<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<(), StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

Initialize storage (create directories, etc.)

fn remove_all<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<(), StorageError>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

Remove all files from storage.

Equivalent to Python’s get_file_storage(data_root_directory).remove_all(). The storage directory itself is preserved; only its contents are deleted.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors