Module task_context
cognee_
lib
0.1.1
Module task_
context
Module Items
Structs
In cognee_
lib::
core
cognee_lib
::
core
Module
task_
context
Structs

Pipeline
Context
Identity of the running pipeline and the data item being processed.
Task
Context
Runtime dependencies and control tokens for a single pipeline task.
Task
Context
Builder
Fluent builder for
TaskContext
.