pub enum DatabaseConnection {
SqlxPostgresPoolConnection(SqlxPostgresPoolConnection),
SqlxSqlitePoolConnection(SqlxSqlitePoolConnection),
Disconnected,
}Expand description
Handle a database connection depending on the backend enabled by the feature
flags. This creates a database pool. This will be Clone unless the feature
flag mock is enabled.
Variants
SqlxPostgresPoolConnection(SqlxPostgresPoolConnection)
Create a PostgreSQL database connection and pool
SqlxSqlitePoolConnection(SqlxSqlitePoolConnection)
Create a SQLite database connection and pool
Disconnected
The connection to the database has been severed
Implementations
Sourceimpl DatabaseConnection
impl DatabaseConnection
Sourcepub fn set_metric_callback<F>(&mut self, _callback: F)
pub fn set_metric_callback<F>(&mut self, _callback: F)
Sets a callback to metric this connection
Sourcepub async fn ping(&self) -> Result<(), DbErr>
pub async fn ping(&self) -> Result<(), DbErr>
Checks if a connection to the database is still valid.
Sourcepub async fn close(self) -> Result<(), DbErr>
pub async fn close(self) -> Result<(), DbErr>
Explicitly close the database connection.
See Self::close_by_ref for usage with references.
Sourcepub async fn close_by_ref(&self) -> Result<(), DbErr>
pub async fn close_by_ref(&self) -> Result<(), DbErr>
Explicitly close the database connection
Sourceimpl DatabaseConnection
impl DatabaseConnection
Sourcepub fn get_postgres_connection_pool(&self) -> &Pool<Postgres>
pub fn get_postgres_connection_pool(&self) -> &Pool<Postgres>
Sourcepub fn get_sqlite_connection_pool(&self) -> &Pool<Sqlite>
pub fn get_sqlite_connection_pool(&self) -> &Pool<Sqlite>